@@ -7,6 +7,7 @@
 #define ITEMBRANCHINDICATORS_H
 
 #include <QModelIndex>
+#include <QPalette>
 #include <QQuickPaintedItem>
 
 class ItemBranchIndicators : public QQuickPaintedItem
@@ -14,16 +15,22 @@ class ItemBranchIndicators : public QQuickPaintedItem
     Q_OBJECT
     QML_ELEMENT
     Q_PROPERTY(QModelIndex modelIndex MEMBER m_index WRITE setModelIndex NOTIFY modelIndexChanged)
+    Q_PROPERTY(bool selected MEMBER m_selected WRITE setSelected NOTIFY selectedChanged)
 public:
+    explicit ItemBranchIndicators(QQuickItem *parent = nullptr);
     void setModelIndex(const QModelIndex &index);
+    void setSelected(bool selected);
     void paint(QPainter *painter) override;
 
 Q_SIGNALS:
     void modelIndexChanged();
+    void selectedChanged();
 
 private:
     std::vector<QModelIndex> parentChain;
     QModelIndex m_index;
+    bool m_selected;
+    QPalette m_palette;
 };
 
 #endif
